# The MIT License (MIT)
# Copyright (c) 2022 by the xcube team and contributors
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from xcube.util.jsonschema import JsonArraySchema
from xcube.util.jsonschema import JsonBooleanSchema
from xcube.util.jsonschema import JsonNumberSchema
from xcube.util.jsonschema import JsonStringSchema

BOOLEAN_SCHEMA = JsonBooleanSchema()
NUMBER_SCHEMA = JsonNumberSchema()
URI_SCHEMA = JsonStringSchema(format='uri')
IDENTIFIER_SCHEMA = JsonStringSchema(min_length=1)
CHUNK_SIZE_SCHEMA = JsonStringSchema(min_length=2)  # TODO: use pattern
STRING_SCHEMA = JsonStringSchema()
PATH_SCHEMA = JsonStringSchema(min_length=1)

BOUNDING_BOX_ITEMS = [
    NUMBER_SCHEMA,
    NUMBER_SCHEMA,
    NUMBER_SCHEMA,
    NUMBER_SCHEMA
]

BOUNDING_BOX_SCHEMA = JsonArraySchema(
    items=BOUNDING_BOX_ITEMS,
    description="Spatial bounding box given as [x-min, y-min, x-max, y-max]."
)

GEO_BOUNDING_BOX_SCHEMA = JsonArraySchema(
    items=BOUNDING_BOX_ITEMS,
    description="Spatial bounding box given as [x-min, y-min, x-max, y-max]"
                " using geographical coordinates."
)

FILE_SYSTEM_SCHEMA = JsonStringSchema(
    enum=['memory', 'obs', 'local', 's3', 'file']
)
